chrome.contextMenus.create({
  id: "convertly",
  title: "Convert with Convertly",
  contexts: ["selection"]
});

chrome.contextMenus.onClicked.addListener((info) => {
  const selectedText = info.selectionText.trim().toLowerCase();
  convertUnits(selectedText);
});

function convertUnits(text) {
	chrome.storage.sync.get(['lengthUnit', 'volumeUnit', 'weightUnit', 'currencyUnit'], (data) => {
		let result = "";

		let cleanedText = text
	.replace(/\u00A0/g, ' ') // pevné medzery
	.replace(/(\d{1,3})((?:\s\d{3})+)([,.]\d+)?/g, (m, p1, p2, p3) => {
		// "1 893,71" → "1893.71"
		const number = (p1 + p2).replace(/\s/g, '') + (p3 ? p3.replace(',', '.') : '');
		return number;
	})
	.replace(/(\d+),(\d{1,2})(?!\d)/g, '$1.$2') // desatinné čiarky 1–2 čísla
	.replace(/(\d),(?=\d{3}\b)/g, '$1') // 3,000.00 → 3000.00
	.replace(/\s+/g, ' ')
	.trim();




		const match = cleanedText.match(/([$€£¥])?\s*(\d+(?:\.\d+)?)\s*([a-zA-Z]{1,5}|[$€£¥])?/i);
		if (!match) return;

		const num = parseFloat(match[2]);
		if (isNaN(num)) return;

		const unitRaw = ((match[1] || '') + (match[3] || '')).replace(/\s+/g, '').toLowerCase();
		const normalizedUnit = normalizeCurrencyUnit(unitRaw);



// Skús najprv meniť menu – ak to je mena, urob konverziu a koniec
if (["USD", "EUR", "GBP", "JPY", "CHF", "AUD", "CZK"].includes(normalizedUnit)) {
	result = convertCurrency(num, normalizedUnit, data.currencyUnit || "EUR");
}




		// Dĺžka
		if (["inch", "in"].includes(unitRaw)) {
			result = convertLength(num, "inch", data.lengthUnit || "cm");
		} else if (unitRaw === "cm") {
			result = convertLength(num, "cm", data.lengthUnit || "m");
		} else if (unitRaw === "m") {
			result = convertLength(num, "m", data.lengthUnit || "cm");
		} else if (["ft", "feet"].includes(unitRaw)) {
			result = convertLength(num, "ft", data.lengthUnit || "m");
		} else if (unitRaw === "km") {
			result = convertLength(num, "km", data.lengthUnit || "m");
    }
      else if (unitRaw === "mm") {
      result = convertLength(num, "mm", data.lengthUnit || "cm");
    }

		// Objem
		else if (unitRaw === "ml") {
			result = convertVolume(num, "ml", data.volumeUnit || "l");
		} else if (["l", "liter"].includes(unitRaw)) {
			result = convertVolume(num, "l", data.volumeUnit || "ml");
		} else if (["gal", "gallon"].includes(unitRaw)) {
			result = convertVolume(num, "gal", data.volumeUnit || "l");
		}

		// Váha
		else if (unitRaw === "g") {
			result = convertWeight(num, "g", data.weightUnit || "kg");
		} else if (unitRaw === "kg") {
			result = convertWeight(num, "kg", data.weightUnit || "g");
		} else if (["lb", "lbs"].includes(unitRaw)) {
			result = convertWeight(num, "lb", data.weightUnit || "kg");
		} else if (unitRaw === "oz") {
			result = convertWeight(num, "oz", data.weightUnit || "g");
		}

		// Mena
		else if (["$", "usd"].includes(unitRaw)) {
			result = convertCurrency(num, "USD", data.currencyUnit || "EUR");
		} else if (["€", "eur"].includes(unitRaw)) {
			result = convertCurrency(num, "EUR", data.currencyUnit || "USD");
		} else if (["£", "gbp"].includes(unitRaw)) {
			result = convertCurrency(num, "GBP", data.currencyUnit || "EUR");
		} else if (["¥", "jpy"].includes(unitRaw)) {
			result = convertCurrency(num, "JPY", data.currencyUnit || "USD");
		} else if (["czk", "kč"].includes(unitRaw)) {
			result = convertCurrency(num, "CZK", data.currencyUnit || "EUR");
		} else if (["chf"].includes(unitRaw)) {
			result = convertCurrency(num, "CHF", data.currencyUnit || "EUR");
		} else if (["aud"].includes(unitRaw)) {
			result = convertCurrency(num, "AUD", data.currencyUnit || "EUR");
		}

		if (result) {
			chrome.storage.sync.set({ lastConversion: result });
		}
	});
}




// Konverzné funkcie
function convertLength(value, from, to) {
  const conversions = {
    inch: 2.54,
    cm: 1,
    m: 100,
    ft: 30.48,
    km: 100000,
    mm: 0.1 // mm → cm
  };
  
  const valueInCm = value * conversions[from];
  const result = valueInCm / conversions[to];
  return `${value} ${from} -> ${result.toFixed(2)} ${to}`;
}

function convertVolume(value, from, to) {
  const conversions = {
    ml: 1,
    l: 1000, // ml
    gal: 3785.41 // ml
  };
  const valueInMl = value * conversions[from];
  const result = valueInMl / conversions[to];
  return `${value} ${from} -> ${result.toFixed(2)} ${to}`;
}

function convertWeight(value, from, to) {
  const conversions = {
    g: 1,
    kg: 1000, // g
    lb: 453.592, // g
    oz: 28.3495 // g
  };
  const valueInG = value * conversions[from];
  const result = valueInG / conversions[to];
  return `${value} ${from} -> ${result.toFixed(2)} ${to}`;
}
function normalizeCurrencyUnit(unit) {
	const map = {
		'$': 'USD',
		'€': 'EUR',
		'£': 'GBP',
		'¥': 'JPY',
		'usd': 'USD',
		'eur': 'EUR',
		'gbp': 'GBP',
		'jpy': 'JPY',
		'chf': 'CHF',
		'aud': 'AUD',
		'czk': 'CZK',
	};

	return map[unit] || unit.toUpperCase();
}
function convertCurrency(value, from, to) {
	const rates = {
		USD: 1.00,
		EUR: 0.90,
		GBP: 0.78,
		JPY: 150,
		CZK: 22.5,
		CHF: 0.95,
		AUD: 1.5
	};

	if (from === to) {
		return `${value} ${from} = ${value.toFixed(2)} ${to}`;
	}

	const valueInUSD = from === "USD" ? value : value / rates[from];
	const result = to === "USD" ? valueInUSD : valueInUSD * rates[to];

	return `${value} ${from} = ${result.toFixed(2)} ${to}`;
}

